@@ -40,6 +40,7 @@ import platform
 from decouple import config, UndefinedValueError
 from numpy import array, float64, int32
 from pathlib import Path
+from collections import defaultdict
 
 # =============================================================================
 # INTERNAL IMPORTS
@@ -57,25 +58,18 @@ from .exceptions import SymupyError, SymupyWarning
 # =============================================================================
 # DEFAULT PATHS TO FIND SIMULATOR PLATFORMS
 # =============================================================================
-DEFAULT_LIB_LINUX = os.path.join(
-    "/", "home", "symudev", "build", "lib", "libSymuVia.so"
-)
 
 DEFAULT_LIB_OSX = os.path.join(
-    "/",
-    "Users",
-    "ladino",
-    "Documents",
-    "01-Platforms",
-    "01-SymuVia",
-    "06-Source",
-    "symudev",
-    "build",
-    "lib",
-    "libSymuVia.dylib",
+    os.getenv("CONDA_PREFIX"), "lib", "libSymuVia.dylib"
 )
 
-DEFAULT_LIB_WINDOWS = ""
+DEFAULT_LIB_LINUX = os.path.join(
+    os.getenv("CONDA_PREFIX"), "lib", "libSymuVia.so"
+)
+
+DEFAULT_LIB_WINDOWS = os.path.join(
+    os.getenv("CONDA_PREFIX"), "lib", "libSymuVia.dll"
+)
 
 if platform.system() == "Darwin":
     try:
@@ -88,7 +82,7 @@ if platform.system() == "Darwin":
         DEFAULT_PATH_SYMUVIA = ""
 elif platform.system() == "Linux":
     try:
-        if Path(DEFAULT_LIB_OSX).exists():
+        if Path(DEFAULT_LIB_LINUX).exists():
             DEFAULT_PATH_SYMUVIA = DEFAULT_LIB_LINUX
         else:
             DEFAULT_PATH_SYMUVIA = config("DEFAULT_LIB_LINUX")
@@ -123,7 +117,7 @@ LAUNCH_MODE = "lite"
 TOTAL_SIMULATION_STEPS = 0
 
 FIELD_DATA = {
-    "@abs": "abscisa",
+    "@abs": "abscissa",
     "@acc": "acceleration",
     "@dst": "distance",
     "@id": "vehid",
@@ -133,6 +127,7 @@ FIELD_DATA = {
     "@vit": "speed",
     "@voie": "lane",
     "@z": "elevation",
+    "@etat_pilotage": "driven",
 }
 
 FIELD_FORMAT = {
@@ -146,6 +141,7 @@ FIELD_FORMAT = {
     "@vit": float,
     "@voie": int,
     "@z": float,
+    "@etat_pilotage": bool,
 }
 
 FLOATFORMAT = float64
